Logic Nets and Blocks
=====================

LogicNets
---------

.. autoclass:: pyrtl.core.LogicNet


Blocks
------

.. autoclass:: pyrtl.core.Block

.. autofunction:: pyrtl.core.working_block

.. autofunction:: pyrtl.core.reset_working_block

.. autofunction:: pyrtl.core.set_working_block

.. autofunction:: pyrtl.core.temp_working_block

.. autofunction:: pyrtl.core.Block.add_wirevector

.. autofunction:: pyrtl.core.Block.remove_wirevector

.. autofunction:: pyrtl.core.Block.add_net

.. autofunction:: pyrtl.core.Block.get_memblock_by_name

.. autofunction:: pyrtl.core.Block.wirevector_subset

.. autofunction:: pyrtl.core.Block.logic_subset

.. autofunction:: pyrtl.core.Block.get_wirevector_by_name

.. autofunction:: pyrtl.core.Block.net_connections

.. autofunction:: pyrtl.core.Block.sanity_check
